pub struct QuoteHeader {
pub version: u16,
pub attestation_key_type: AttestionKeyType,
pub tee_type: TEEType,
pub reserved1: [u8; 2],
pub reserved2: [u8; 2],
pub qe_vendor_id: [u8; 16],
pub user_data: [u8; 20],
}Expand description
A TDX quote header
Fields
version: u16Quote version (4 or 5)
attestation_key_type: AttestionKeyTypeType of the Attestation Key used by the Quoting Enclave
tee_type: TEETypeType of TEE used
reserved1: [u8; 2]Currently unused
reserved2: [u8; 2]Currently unused
qe_vendor_id: [u8; 16]UUID for the quoting enclave vendor
user_data: [u8; 20]Trait Implementations
Sourceimpl Debug for QuoteHeader
impl Debug for QuoteHeader
impl Eq for QuoteHeader
Sourceimpl PartialEq for QuoteHeader
impl PartialEq for QuoteHeader
Sourcefn eq(&self, other: &QuoteHeader) -> bool
fn eq(&self, other: &QuoteHeader) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for QuoteHeader